@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjTaskReport.h 1214 2005-11-17 20:05:36Z cs $
+ * $Id: TjTaskReport.h 1315 2006-08-11 21:05:41Z cs $
  */
 
 #ifndef _TjTaskReport_h_
@@ -25,7 +25,7 @@ class TjPrintReport;
 class TjTaskReport : public TjReport
 {
 public:
-    TjTaskReport(QWidget* p, Report* const rDef,
+    TjTaskReport(QWidget* p, ReportManager* m, Report* const rDef,
                  const QString& n = QString::null);
     virtual ~TjTaskReport();
 
@@ -37,8 +37,8 @@ protected:
     virtual bool generateList();
 
     virtual QString generateStatusBarText(const QPoint& pos,
-                                          const CoreAttributes* ca,
-                                          const CoreAttributes* parent) const;
+                                          CoreAttributes* ca,
+                                          CoreAttributes* parent);
 
 private:
     QListViewItem* getTaskListEntry(const Task* t);
