@@ -1,13 +1,14 @@
 /*
  * The TaskJuggler Project Management Software
  *
- * Copyright (c) 2001, 2002, 2003, 2004, 2005 by Chris Schlaeger <cs@kde.org>
+ * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006
+ * by Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: taskjugglerview.cpp 1232 2005-12-01 10:55:42Z cs $
+ * $Id: taskjugglerview.cpp 1328 2006-09-03 10:24:28Z cs $
  */
 
 #include "taskjugglerview.h"
@@ -30,6 +31,7 @@
 #include <qprogressbar.h>
 #include <qtimer.h>
 #include <qlistview.h>
+#include <qpushbutton.h>
 
 #include <kdebug.h>
 #include <kmainwindow.h>
@@ -376,7 +378,7 @@ TaskJugglerView::newInclude()
     // Show the new file in the editor.
     showEditor();
     // Save the file so that it physically exists.
-    save();
+    fileManager->saveCurrentFile();
 }
 
 QString
@@ -416,6 +418,14 @@ TaskJugglerView::pickTemplateFile(const QString& extension)
         KListViewItem* lvi = new KListViewItem(selector->templateList, name);
         lvi->setText(1, *it);
     }
+
+    // Select the first entry in the list and enable the OK button.
+    if (selector->templateList->firstChild())
+    {
+        selector->templateList->firstChild()->setSelected(true);
+        selector->buttonOk->setEnabled(true);
+    }
+
     if (selector->exec() == QDialog::Rejected)
         return QString::null;
 
@@ -491,35 +501,15 @@ TaskJugglerView::loadAfterTimerTimeout()
     loadProject(urlToLoad);
 }
 
-void
-TaskJugglerView::save()
-{
-    fileManager->saveCurrentFile();
-}
-
-void
-TaskJugglerView::saveAs()
-{
-    KURL url = KFileDialog::getSaveURL
-        (QString::null, "*.tjp, *.tji", this, i18n("Save file as"));
-
-    if (!url.isEmpty() && url.isValid())
-        saveAs(url);
-}
-
-void
-TaskJugglerView::saveAs(const KURL& url)
-{
-    fileManager->saveCurrentFileAs(url);
-    // Update window caption.
-    showEditor();
-}
-
 void
 TaskJugglerView::close()
 {
     fileManager->saveCurrentFile(true);
     fileManager->closeCurrentFile();
+    // If we have closed the last file, we need to hide the Editor as well.
+    if (!fileManager->getCurrentFile())
+        hideEditor();
+
     // In case we closed the master file, we will close the whole project.
     if (!fileManager->getMasterFile())
         closeProject();
@@ -552,70 +542,11 @@ bool
 TaskJugglerView::quit(bool force)
 {
     fileManager->saveAllFiles(!force);
+    fileManager->hideEditor();
 
     return true;
 }
 
-void
-TaskJugglerView::undo()
-{
-    fileManager->undo();
-}
-
-void
-TaskJugglerView::redo()
-{
-    fileManager->redo();
-}
-
-void
-TaskJugglerView::cut()
-{
-    fileManager->cut();
-}
-
-void
-TaskJugglerView::copy()
-{
-    fileManager->copy();
-}
-
-void
-TaskJugglerView::paste()
-{
-    fileManager->paste();
-}
-
-void
-TaskJugglerView::selectAll()
-{
-    fileManager->selectAll();
-}
-
-void
-TaskJugglerView::find()
-{
-    fileManager->find();
-}
-
-void
-TaskJugglerView::findNext()
-{
-    fileManager->findNext();
-}
-
-void
-TaskJugglerView::findPrevious()
-{
-    fileManager->findPrevious();
-}
-
-void
-TaskJugglerView::insertDate()
-{
-    fileManager->insertDate();
-}
-
 void
 TaskJugglerView::schedule()
 {
@@ -810,12 +741,17 @@ TaskJugglerView::loadProject(const KURL& url)
         showEditor();
         mw->messageListView->clearSelection();
         QListViewItem* lvi = mw->messageListView->firstChild();
-        mw->messageListView->setCurrentItem(lvi);
-        lvi->setSelected(true);
-        messageListClicked(lvi);
+        if (lvi)
+        {
+            /* Prevent GUI crash in case the back-end reports an error but
+             * does not provide an error message. */
+            mw->messageListView->setCurrentItem(lvi);
+            lvi->setSelected(true);
+            messageListClicked(lvi);
 
-        mainWindow->action("next_problem")->setEnabled(true);
-        mainWindow->action("previous_problem")->setEnabled(true);
+            mainWindow->action("next_problem")->setEnabled(true);
+            mainWindow->action("previous_problem")->setEnabled(true);
+        }
     }
     else
     {
@@ -1023,7 +959,7 @@ TaskJugglerView::focusBigTab(QWidget*)
                     fileManager->getCurrentFile()->getUniqueName();
             fileManager->enableEditorActions(TRUE);
             mw->listViews->setCurrentIndex(lastBrowserUsedWithEditor);
-            fileManager->setFocusToEditor();
+            fileManager->showEditor();
             reportManager->enableReportActions(false);
 
             break;
@@ -1043,8 +979,7 @@ TaskJugglerView::focusBigTab(QWidget*)
             // Enable report menu and toolbar actions.
             reportManager->enableReportActions(true);
 
-            // Disable all editor actions.
-            fileManager->enableEditorActions(FALSE);
+            hideEditor();
 
             break;
     }
@@ -1064,12 +999,20 @@ TaskJugglerView::showEditor()
     (dynamic_cast<TaskJuggler*>(parent()))->changeCaption(windowCaption);
 
     mw->bigTab->showPage(mw->editorTab);
-    fileManager->setFocusToEditor();
+    fileManager->showEditor();
+}
+
+void
+TaskJugglerView::hideEditor()
+{
+    fileManager->hideEditor();
 }
 
 void
 TaskJugglerView::showReport()
 {
+    hideEditor();
+
     if (mw->listViews->currentItem() != mw->reportsPage)
         lastBrowserUsedWithEditor = mw->listViews->currentIndex();
 
