@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportElement.h 1215 2005-11-17 20:42:48Z cs $
+ * $Id: ReportElement.h 1312 2006-07-22 14:28:45Z cs $
  */
 #ifndef _ReportElement_h_
 #define _ReportElement_h_
@@ -268,7 +268,7 @@ protected:
     ReportElement() { }
 
     void addCustomAttributeColumns
-        (const QDict<const CustomAttributeDefinition>& cad);
+        (const QDict<CustomAttributeDefinition>& cad);
 
     void errorMessage(const char* msg, ... );
 
