@@ -1,13 +1,14 @@
 /*
  * task.h - TaskJuggler
  *
- * Copyright (c) 2001, 2002, 2003, 2004, 2005 by Chris Schlaeger <cs@kde.org>
+ * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006
+ * Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Task.h 1224 2005-11-22 16:27:52Z cs $
+ * $Id: Task.h 1268 2006-02-19 13:35:03Z cs $
  */
 
 #ifndef _Task_h_
@@ -289,6 +290,7 @@ public:
     void finishScenario(int sc);
     void computeCriticalness(int sc);
     double getCriticalness(int sc) const { return scenarios[sc].criticalness; }
+    void checkAndMarkCriticalPath(int sc, double minSlack);
 
     void computePathCriticalness(int sc);
     double getPathCriticalness(int sc) const
@@ -296,6 +298,19 @@ public:
         return scenarios[sc].pathCriticalness;
     }
 
+    bool isOnCriticalPath(int sc, bool leavesOnly = true) const
+    {
+        if (!isLeaf() && leavesOnly)
+            return false;
+
+        return scenarios[sc].isOnCriticalPath;
+    }
+
+    bool hasCriticalLinkTo(int sc, const Task* t) const
+    {
+        return scenarios[sc].criticalLinks.containsRef(t);
+    }
+
     bool hasExtraValues(int sc) const;
 
     bool isContainer() const { return !sub->isEmpty(); }
@@ -308,10 +323,15 @@ public:
 
     bool preScheduleOk(int sc);
     bool scheduleOk(int sc, int& errors) const;
-    void initLoopDetector()
-    {
-    }
-    bool loopDetector() const;
+    /**
+     * Checks for loops in task interdependencies starting with the current
+     * task.
+     * @param ckedTaskList The list of already checked tasks. Will be appended
+     * to.
+     * @retval true if a loop was detected.
+     * @retval false otherwise.
+     */
+    bool loopDetector(LDIList& chkedTaskList) const;
     bool checkDetermination(int sc) const;
     void computeBuffers();
     time_t nextSlot(time_t slotDuration) const;
@@ -333,8 +353,16 @@ public:
     void loadFromXML( QDomElement& parent, Project *p );
     void allocationFromXML( const QDomElement& );
 private:
-    bool loopDetection(LDIList& list, bool atEnd, LoopDetectorInfo::FromWhere
-                       caller) const;
+    /**
+     * Checks for loops in task interdependencies starting with the current
+     * task under ASAP or ALAP scheduling.
+     * @param ckedTaskList The list of already checked tasks. Will be appended
+     * to.
+     * @retval true if a loop was detected.
+     * @retval false otherwise.
+     */
+    bool loopDetection(LDIList& list, LDIList& chkedTaskList, bool atEnd,
+                       LoopDetectorInfo::FromWhere caller) const;
     bool checkPathForLoops(LDIList& list, bool atEnd) const;
     bool scheduleContainer(int sc, bool safeMode);
     Task* subFirst() { return (Task*) sub->first(); }
@@ -363,6 +391,9 @@ private:
     double computeBackwardCriticalness(int sc);
     double computeForwardCriticalness(int sc);
 
+    bool analyzePath(int sc, double minSlack, time_t pathStart,
+                     long busyTime);
+
     bool countMilestones(int sc, time_t now, int& totalMilestones,
                          int& completedMilestones,
                          int& reportedCompletedMilestones);
