@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: debug.h 1214 2005-11-17 20:05:36Z cs $
+ * $Id: debug.h 1280 2006-03-11 15:17:26Z cs $
  */
 
 #ifndef _debug_h_
@@ -23,19 +23,21 @@
 #define DEBUGEX(l) ((DEBUGMODE & 16) && DEBUGLEVEL >= l) // Expression Tree Ev.
 #define DEBUGMA(l) ((DEBUGMODE & 32) && DEBUGLEVEL >= l) // Macro Expander
 #define DEBUGOP(l) ((DEBUGMODE & 64) && DEBUGLEVEL >= l) // Optimizer
+#define DEBUGPA(l) ((DEBUGMODE & 128) && DEBUGLEVEL >= l) // Critical Path
+                                                          // Analyzer
 
 class DebugController
 {
 public:
     DebugController() : debugLevel(0), debugMode(-1) { }
     ~DebugController() { }
-    
+
     void setDebugLevel(int l)
     {
         debugLevel = l;
     }
     int getDebugLevel() const { return debugLevel; }
-    
+
     void setDebugMode(int m)
     {
         debugMode = m;
